# How this folder works


The file `uncertainties.rst` is automatically generated by `conf.py` at build time.

The other files contain the extented infomration for each of 
the uncertainty that should go in the documentation.